@@ -4,8 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION       = '0.03_01';
-our $SWFED_VERSION = '0.56';
+our $VERSION = '0.01';
 
 require XSLoader;
 XSLoader::load('SWFEditor', $VERSION);
@@ -19,7 +18,7 @@ sub new {
     return $self;
 }
 
-sub DESTROY {
+sub DESTORY {
     my $self = shift;
     _swf_object_close($self);
 }
@@ -200,16 +199,6 @@ sub remove_tag {
     return $self->_remove_tag($tag_seqno, $tag_seqno_in_sprite);
 }
 
-sub replace_mld_data {
-    my $self     = shift;
-    my $sound_id = shift;
-    my $data     = shift;
-    return $self->_replace_mld_data (
-        $sound_id,
-        _load($data),
-    );
-}
-
 sub _load {
     my $input = shift;
     if (ref($input) eq 'SCALAR') {
@@ -356,7 +345,7 @@ Implemented function list
 
 =item $swfed->get_png_data(int $image_id)
 
-=item $swfed->replace_bitmap_data(hashref \%image_cond | $image_id, string $bitmapdata, string $alphadata = undef, hashref \%opts | int $without_converting)
+=item $swfed->replace_bitmap_data(hashref \%image_cond | $image_id, string $bitmapdata, string $alphadata = undef, boolean $without_converting = 0)
 
 =item $swfed->replace_png_data($image_id, $pngdata)
 
@@ -416,10 +405,6 @@ Implemented function list
 
 SWF Editor for PHP: L<http://sourceforge.jp/projects/swfed/>
 
-=head1 RESOURCES
-
-REPOSITORY: L<https://github.com/mix3/p5-SWFEditor/>
-
 =head1 AUTHOR
 
 Wataru Seto(mix3) E<lt>himachocost333@gmail.comE<gt>
